@@ -4,22 +4,23 @@ use strict;
 use warnings;
 
 use Carp;
-use Raisin::Attributes;
+use Plack::Util::Accessor qw(
+    named
+    required
+
+    default
+    desc
+    enclosed
+    name
+    regex
+    type
+);
+
 use Raisin::Util;
 
 my @ATTRIBUTES = qw(name type default regex desc);
 my @LOCATIONS = qw(path formData body header query);
 
-has 'named';
-has 'required';
-
-has 'default';
-has 'name';
-has 'type';
-has 'regex';
-has 'desc';
-has 'enclosed';
-
 sub new {
     my ($class, %args) = @_;
     my $self = bless {}, $class;
@@ -96,7 +97,7 @@ sub validate {
     my ($self, $ref_value, $quiet) = @_;
 
     # Required and empty
-    # Only optional parameters can has default value
+    # Only optional parameters can have default value
     if ($self->required && !defined($$ref_value)) {
         Raisin::log(warn => '`%s` is required', $self->name) unless $quiet;
         return;
